`vcd-cli` is a command line interface for VMware vCloud Director.

`vcd-cli` allows system administrators and tenants to perform operations from
the command line for convenience and automation.

In order to execute `cse` commands, see [Adding Extensions](extending.html)

See the list of available [commands](commands.html) and the [install](install.html)
instructions for more information.
